@@ -193,7 +193,7 @@ def imagine(
                     )
 
                 if prompt.fix_faces:
-                    from enhancers.face_restoration_codeformer import codeformer_model
+                    from classy_imaginary.enhancers.face_restoration_codeformer import codeformer_model
                     codeformer_net_model = codeformer_model()
 
                 result = _generate_single_image(
