@@ -1,13 +1,12 @@
-import os.path
-import sys
-
-import torch
-
-from classy_imaginary.utils import get_device, get_hardware_description
-from classy_imaginary.version import get_version
-
-
 def get_debug_info():
+    import os.path
+    import sys
+
+    import psutil
+    import torch
+
+    from classy_imaginary.utils import get_device, get_hardware_description
+    from classy_imaginary.version import get_version
 
     data = {
         "imaginairy_version": get_version(),
@@ -18,6 +17,7 @@ def get_debug_info():
         "torch_version": torch.__version__,
         "platform": sys.platform,
         "hardware_description": get_hardware_description(get_device()),
+        "ram_gb": round(psutil.virtual_memory().total / (1024**3), 2),
     }
     if torch.cuda.is_available():
         device_props = torch.cuda.get_device_properties(0)
@@ -30,4 +30,10 @@ def get_debug_info():
                 "graphics_card_hw_version": f"{device_props.major}.{device_props.minor}",
             }
         )
+    elif "mps" in get_device():
+        data.update(
+            {
+                "graphics_card": "Apple MPS",
+            }
+        )
     return data
